@@ -4,8 +4,9 @@ import os
 import numpy as np
 from scipy.stats import norm
 from .base import _BaseSumStats, _H5SSConnection
-from pysumstats.plot import manhattan
-from pysumstats.plot import qqplot
+from .plot import manhattan
+from .plot.qq import qqplot
+from .plot.manhattan import manhattan
 
 pd.options.mode.chained_assignment = None
 
